
{% load i18n %}

<table class="table table-striped aa-sovtimer-campaigns" style="width: 100%; border-collapse: collapse !important;">
    <thead>
        <th class="aa-sovtimer-campaigns-type-column">{% translate 'Type' %}</th>
        <th class="aa-sovtimer-campaigns-system-column">{% translate 'System' %}</th>
        <th class="aa-sovtimer-campaigns-constellation-column">{% translate 'Constellation' %}</th>
        <th class="aa-sovtimer-campaigns-region-column">{% translate 'Region' %}</th>
        <th class="aa-sovtimer-campaigns-defender-column">{% translate 'Owner / Defender' %}</th>
        <th class="aa-sovtimer-campaigns-adm-column">{% translate 'ADM' %}</th>
        <th class="aa-sovtimer-campaigns-start-datetime-column">{% translate 'Start' %}</th>
        <th class="aa-sovtimer-campaigns-remaining-time-column">{% translate 'Remaining' %}</th>
        <th class="aa-sovtimer-campaigns-progress-column">{% translate 'Progress' %}</th>
    </thead>

    <tbody></tbody>
</table>
